@@ -9,7 +9,7 @@ use Math::BigNum qw();
 
 use Class::Multimethods qw();
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =encoding utf8
 
@@ -19,7 +19,7 @@ Math::BigNum::Inf - Represents the +/-Infinity value.
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =head1 SYNOPSIS
 
@@ -177,9 +177,8 @@ Negative value of C<$x>, changing C<$x> in-place.
 =cut
 
 sub bneg {
-    my ($x) = @_;
-    Math::GMPq::Rmpq_neg($$x, $$x);
-    $x;
+    Math::GMPq::Rmpq_neg(${$_[0]}, ${$_[0]});
+    $_[0];
 }
 
 =head2 abs
@@ -205,9 +204,8 @@ Sets C<$x> in-place to its absolute value.
 =cut
 
 sub babs {
-    my ($x) = @_;
-    Math::GMPq::Rmpq_abs($$x, $$x);
-    $x;
+    Math::GMPq::Rmpq_abs(${$_[0]}, ${$_[0]});
+    $_[0];
 }
 
 =head2 copy
@@ -1564,12 +1562,39 @@ Class::Multimethods::multimethod brsft => qw(Math::BigNum::Inf Math::BigNum::Nan
 
 *li2 = \&ninf;
 *ln  = \&inf;
+*bln = \&binf;
+
+# log(+/-Inf) = +Inf
+Class::Multimethods::multimethod log => qw(Math::BigNum::Inf) => \&inf;
+
+# log(+/-Inf) / log(42) = +Inf
+# log(+/-Inf) / log(-1) = (-i)*Inf       --> NaN in our case
+# log(+/-Inf) / log(0)  = undefined      --> NaN
+
+Class::Multimethods::multimethod log => qw(Math::BigNum::Inf Math::BigNum) => sub {
+    Math::GMPq::Rmpq_sgn(${$_[1]}) <= 0 ? nan() : inf();
+};
 
-Class::Multimethods::multimethod log => qw(Math::BigNum::Inf)                   => \&inf;
-Class::Multimethods::multimethod log => qw(Math::BigNum::Inf Math::BigNum)      => \&inf;
 Class::Multimethods::multimethod log => qw(Math::BigNum::Inf Math::BigNum::Inf) => \&nan;
 Class::Multimethods::multimethod log => qw(Math::BigNum::Inf Math::BigNum::Nan) => \&nan;
 
+Class::Multimethods::multimethod log => qw(Math::BigNum::Inf *) => sub {
+    $_[0]->log(Math::BigNum->new($_[1]));
+};
+
+Class::Multimethods::multimethod blog => qw(Math::BigNum::Inf) => \&binf;
+
+Class::Multimethods::multimethod blog => qw(Math::BigNum::Inf Math::BigNum) => sub {
+    Math::GMPq::Rmpq_sgn(${$_[1]}) <= 0 ? $_[0]->bnan : $_[0]->binf;
+};
+
+Class::Multimethods::multimethod blog => qw(Math::BigNum::Inf Math::BigNum::Inf) => \&bnan;
+Class::Multimethods::multimethod blog => qw(Math::BigNum::Inf Math::BigNum::Nan) => \&bnan;
+
+Class::Multimethods::multimethod blog => qw(Math::BigNum::Inf *) => sub {
+    $_[0]->blog(Math::BigNum->new($_[1]));
+};
+
 sub gamma {
     $_[0]->is_neg ? nan() : $_[0]->copy;
 }
