@@ -7,7 +7,7 @@ use warnings;
 use Math::GMPq qw();
 use Math::BigNum qw();
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =encoding utf8
 
@@ -17,7 +17,7 @@ Math::BigNum::Nan - Represents the Not-a-Number value.
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =head1 SYNOPSIS
 
@@ -206,6 +206,20 @@ Always returns Nan.
 *bsub  = \&_self;
 *bisub = \&_self;
 
+=head2 mul / bmul
+
+    $x->mul(Any)                   # => Nan
+    $x->bmul(Any)                  # => Nan
+
+Always returns Nan.
+
+=cut
+
+*mul   = \&nan;
+*imul  = \&nan;
+*bmul  = \&_self;
+*bimul = \&_self;
+
 =head2 div / bdiv
 
     $x->div(Any)                   # => Nan
@@ -310,6 +324,7 @@ sub cmp { }
 *log2  = \&nan;
 *log10 = \&nan;
 *blog  = \&_self;
+*bln   = \&_self;
 
 *exp   = \&nan;
 *exp2  = \&nan;
